@@ -26,9 +26,6 @@ email                : marco.hugentobler at sourcepole dot com
 #include "qgsmultipoint.h"
 #include "qgspolygon.h"
 #include "qgsmultipolygon.h"
-#include "qgstriangle.h"
-#include "qgstriangulatedsurface.h"
-#include "qgspolyhedralsurface.h"
 #include "qgswkbptr.h"
 #include "qgsgeos.h"
 #include "qgsfeedback.h"
@@ -385,16 +382,12 @@ bool QgsGeometryCollection::fromWkb( QgsConstWkbPtr &wkbPtr )
 
 bool QgsGeometryCollection::fromWkt( const QString &wkt )
 {
-  return fromCollectionWkt( wkt, QVector<QgsAbstractGeometry *>() << new QgsPoint << new QgsLineString << new QgsPolygon //
-                            << new QgsCircularString << new QgsCompoundCurve       //
-                            << new QgsCurvePolygon                                 //
-                            << new QgsMultiPoint << new QgsMultiLineString         //
-                            << new QgsMultiPolygon << new QgsGeometryCollection    //
-                            << new QgsMultiCurve << new QgsMultiSurface            //
-                            << new QgsTriangle << new QgsPolyhedralSurface         //
-                            << new QgsTriangulatedSurface                          //
-                            ,
-                            QStringLiteral( "GeometryCollection" ) );
+  return fromCollectionWkt( wkt, QVector<QgsAbstractGeometry *>() << new QgsPoint << new QgsLineString << new QgsPolygon
+                            << new QgsCircularString << new QgsCompoundCurve
+                            << new QgsCurvePolygon
+                            << new QgsMultiPoint << new QgsMultiLineString
+                            << new QgsMultiPolygon << new QgsGeometryCollection
+                            << new QgsMultiCurve << new QgsMultiSurface, QStringLiteral( "GeometryCollection" ) );
 }
 
 int QgsGeometryCollection::wkbSize( QgsAbstractGeometry::WkbFlags flags ) const
@@ -1064,7 +1057,7 @@ void QgsGeometryCollection::swapXy()
 
 QgsGeometryCollection *QgsGeometryCollection::toCurveType() const
 {
-  std::unique_ptr< QgsGeometryCollection > newCollection( new QgsGeometryCollection() );
+  auto newCollection = std::make_unique<QgsGeometryCollection>();
   newCollection->reserve( mGeometries.size() );
   for ( QgsAbstractGeometry *geom : mGeometries )
   {
@@ -1083,7 +1076,7 @@ const QgsAbstractGeometry *QgsGeometryCollection::simplifiedTypeRef() const
 
 QgsGeometryCollection *QgsGeometryCollection::simplifyByDistance( double tolerance ) const
 {
-  std::unique_ptr< QgsGeometryCollection > res = std::make_unique< QgsGeometryCollection >();
+  auto res = std::make_unique< QgsGeometryCollection >();
   res->reserve( mGeometries.size() );
   for ( int i = 0; i < mGeometries.size(); ++i )
   {
